@@ -26,7 +26,7 @@ if __name__ == '__main__':
     from optparse import OptionParser
 
     p = OptionParser()
-    p.set_usage('rst_errors.py CONFIG_FILE')
+    p.set_usage('%prog CONFIG_FILE')
     p.set_description(__doc__)
 
     opts, args = p.parse_args(sys.argv[1:])
